/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.internal.command;

import java.util.EventObject;

import org.eclipse.emf.common.command.CommandStackListener;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.CommandStack;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * This command stack wraps the tooling kernel command stack. Execute, isDirty,
 * undo and redo are forwarded, as well as the listener stuff.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: B252906D51C0DA4FF7E523D4CE6C6505
 */
public class GEF2ToolingKernelCommandStack extends CommandStack implements CommandStackListener {

	/** Stores the underlying {@link ITopLevelElement}. */
	private final ITopLevelElement context;

	/** Constructor. */
	public GEF2ToolingKernelCommandStack(EObject modelElement) {
		context = IPersistencyService.getInstance().getTopLevelElementFor(modelElement);
		context.addCommandStackListener(this);
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		context.removeCommandStackListener(this);
		super.dispose();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canRedo() {
		return context.canRedo();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo() {
		return context.canUndo();
	}

	/** {@inheritDoc} */
	@Override
	public void execute(final Command command) {
		context.runAsCommand(new Runnable() {

			@Override
			public void run() {
				command.execute();
			}
		});
	}

	/** {@inheritDoc} */
	@Override
	public Command getRedoCommand() {
		return new TopLevelElementContext2GEFCommand();
	}

	/** {@inheritDoc} */
	@Override
	public Command getUndoCommand() {
		return new TopLevelElementContext2GEFCommand();
	}

	/** {@inheritDoc} */
	@Override
	public void redo() {
		context.redo();
	}

	/** {@inheritDoc} */
	@Override
	public void undo() {
		context.undo();
	}

	/** {@inheritDoc} */
	@Override
	public void commandStackChanged(EventObject event) {
		notifyListeners();
	}

	/** {@inheritDoc} */
	@Override
	public boolean isDirty() {
		return context.isDirty();
	}

	/** This class wraps an EMF command in a GEF command. */
	private class TopLevelElementContext2GEFCommand extends Command {

		/** {@inheritDoc} */
		@Override
		public boolean canExecute() {
			// wrapper can never be executed; undo/redo only
			return false;
		}

		/** {@inheritDoc} */
		@Override
		public boolean canUndo() {
			return context.canUndo();
		}

		/** {@inheritDoc} */
		@Override
		public void execute() {
			// never called
		}

		/** {@inheritDoc} */
		@Override
		public String getLabel() {
			return "";
		}

		/** {@inheritDoc} */
		@Override
		public void redo() {
			context.redo();
		}

		/**
		 * {@inheritDoc}
		 * 
		 * @throws UnsupportedOperationException
		 *             as this is not supported.
		 */
		@Override
		public void setLabel(String label) {
			throw new UnsupportedOperationException();
		}

		/** {@inheritDoc} */
		@Override
		public void undo() {
			context.undo();
		}
	}
}
