/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.layout.auto;

import static org.fortiss.tooling.kernel.utils.EcoreUtils.pickInstanceOf;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.resource.ImageDescriptor;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.ToolingBaseUIActivator;
import org.fortiss.tooling.kernel.model.IProjectRootElement;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.extension.data.ContextMenuContextProvider;

/**
 * Context menu entry to automatic layout {@link IHierarchicElement}-based models.
 * 
 * @author barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 2EC00DB461A5106CEB42DF8819159504
 */
public class AutoLayoutMenu implements IContextMenuContributor {

	/** String appearing in the context menu. */
	private static String MENU_NAME = "Automatic layout";

	/** Declares where is located the icon to use for the menu contribution */
	private static String MENU_ICON = "icons/autolayout.png";

	/** Returns the icon that is visible in the context menu for this entry. */
	protected ImageDescriptor getActionIcon() {
		return ToolingBaseUIActivator.getImageDescriptor(MENU_ICON);
	}

	/** {@link Action} to execute automatic layout. */
	protected class LaunchAutoLayoutAction extends Action {

		/** {@link IHierarchicElement} selected by user */
		private final IHierarchicElement element;

		/** Constructor. */
		public LaunchAutoLayoutAction(IHierarchicElement recGraph) {
			super(MENU_NAME, getActionIcon());
			this.element = recGraph;
		}

		/** {@inheritDoc} */
		@Override
		public void run() {
			IAutoLayouter layouter = new KielerAutoLayouter();
			layouter.performAutoLayout(element);
		}
	}

	/** {@inheritDoc} */
	@Override
	public List<IContributionItem> getContributedItems(EObject selection,
			ContextMenuContextProvider contextProvider) {
		if(selection instanceof IHierarchicElement) {
			IHierarchicElement element = (IHierarchicElement)selection;
			// Skip single top-level model element (e.g., AF3 component architecture)
			if(element instanceof IProjectRootElement && element.getContainedElements().size() == 1) {
				// There is exactly one child element
				element = element.getContainedElements().get(0);
			}
			if(!pickInstanceOf(ILayoutedModelElement.class, element.getContainedElements())
					.isEmpty()) {
				List<IContributionItem> contributionItems = new ArrayList<IContributionItem>();
				contributionItems.add(new ActionContributionItem(
						new LaunchAutoLayoutAction(element)));
				return contributionItems;
			}
		}
		return Collections.emptyList();
	}

	/** {@inheritDoc} */
	@Override
	public String getMenuSectionID() {
		return null;
	}
}
