/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.compose;

import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.kernel.extension.data.IConnectionCompositionContext;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * Base implementation for supporting direct connection of two {@link IHierarchicElement}s.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 6DB675BD3A0953264509F4D152177632
 */
public abstract class HierarchicElementConnectionCompositorBase<HE extends IHierarchicElement, S extends IHierarchicElement, T extends IHierarchicElement>
		extends ConnectionCompositorBase<HE, S, T> {

	/** Creates the application specific entry {@link IConnector} model element. */
	protected abstract IConnector createEntryConnector();

	/** Creates the application specific exit {@link IConnector} model element. */
	protected abstract IConnector createExitConnector();

	/** {@inheritDoc} */
	@Override
	public boolean canConnect(S source, T target, HE parent, IConnectionCompositionContext context) {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	public boolean connect(S source, T target, HE parent, IConnectionCompositionContext context) {
		// By default, exit connectors are source connectors.
		// Explanation: exit connectors exit a hierarchically contained model element, i.e., it goes
		// from the "inside" to the "outside" of the element. Most of the time (hence the face that
		// it is the default behavior) a connection is drawn from "outside" the element, therefore
		// the exit connector is considered as the source by default.
		IConnector sourceConnector = createExitConnector();
		avoidDuplicateConnectorName(source, sourceConnector);
		// And conversely entry connectors are target connectors.
		IConnector targetConnector = createEntryConnector();
		avoidDuplicateConnectorName(target, targetConnector);

		createNewSourceDropContext(source, context, sourceConnector);
		createNewTargetDropContext(target, context, targetConnector);

		ITopLevelElement topElement =
				IPersistencyService.getInstance().getTopLevelElementFor(parent);
		createConnection(sourceConnector, targetConnector, parent, topElement);
		return true;
	}
}
