/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createPoint;
import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createPoints;

import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.Point;
import org.fortiss.tooling.base.model.layout.Points;

/**
 * Utility class for {@link Points} layout data, i.e., a series of points
 * usually encountered with layouts of connections.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 380CF1EEA01A6A45DACF48792180FC56
 */
public final class PointsUtils {

	/**
	 * Returns a {@link Points} layout data object with the given key.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @return the {@link Points} object stored under the layout key.
	 */
	public static Points getPoints(ILayoutedModelElement layouted, String key) {
		for(ILayoutData ld : layouted.getLayoutData()) {
			if(ld.getKey().equals(key) || ld instanceof Points) {
				return (Points)ld;
			}
		}
		return null;
	}

	/**
	 * Sets a {@link Points} layout data.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @param points
	 *            the {@link Points} object
	 */
	public static void setPoints(ILayoutedModelElement layouted, String key, Points points) {
		Points old = getPoints(layouted, key);
		if(old != null) {
			layouted.getLayoutData().remove(old);
		}

		Points pts = createPoints(key);
		for(Point p : points.getPoints()) {
			Point np = createPoint(p.getX(), p.getY(), null);
			pts.getPoints().add(np);
		}
		layouted.getLayoutData().add(pts);
	}
}
