/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.BaseLabelProvider;
import org.eclipse.jface.viewers.IDecoration;
import org.eclipse.jface.viewers.ILightweightLabelDecorator;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;
import org.fortiss.tooling.kernel.ui.ESharedImages;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;

/**
 * Label decorator for the {@link IMarkerService} decorations: errors, warnings, etc.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 27024A84AE7641AEE41F6A682F825DAD
 */
public final class MarkerServiceLabelDecorator extends BaseLabelProvider implements
		ILightweightLabelDecorator {

	/** {@inheritDoc} */
	@Override
	public void decorate(Object element, IDecoration decoration) {
		if(element instanceof EObject) {
			EObject modelElement = (EObject)element;
			ESeverity highest = IMarkerService.getInstance().getHighestViolationSeverity(modelElement);
			// TODO (FH): https://af3.fortiss.org/issues/388
			// use preferences settings here
			switch(highest) {
				case FATAL:
					decoration.addOverlay(ESharedImages.FATAL_OVERLAY.getImageDescriptor());
					break;
				case ERROR:
					decoration.addOverlay(ESharedImages.ERROR_OVERLAY.getImageDescriptor());
					break;
				case WARNING:
					decoration.addOverlay(ESharedImages.WARNING_OVERLAY.getImageDescriptor());
					break;
				default:
					// ignore info and debug
			}
		}
	}
}
