/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details;

import java.util.HashMap;

import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.IIntrospectionItem;
import org.fortiss.tooling.kernel.introspection.items.ConnectionCompositorServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.ConstraintCheckerServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.ConstraintVerificationServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.EclipseResourceStorageServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.ElementCompositorServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.LibraryServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.MigrationServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.PersistencyServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.PrototypeServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.items.TransformationServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.AllocationEditPartFactoryServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ConnectionCompositorServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ConstraintCheckerServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ConstraintServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ConstraintUIServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ContextMenuServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.EclipseResourceStorageProviderIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.EditPartFactoryServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ElementCompositorServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.LibraryServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.MigrationServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ModelEditorBindingServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.ModelElementHandlerServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.PersistencyServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.PrototypeServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.handler.TransformationServiceIntrospectionDetailsUIHandler;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.AllocationEditPartFactoryServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.ConstraintUIServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.ContextMenuServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.EditPartFactoryServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.ModelEditorBindingServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.ModelElementHandlerServiceIntrospectionDetailsItem;

/**
 * Registry class to provide the details GUI for a given {@link IIntrospectionItem}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 6DB43FF0D270D10239E98244266BA9A7
 */
public final class KISSDetailsUIRegistry {
	/** Returns the singleton instance of the service. */
	private static final KISSDetailsUIRegistry INSTANCE = new KISSDetailsUIRegistry();

	/** Returns the singleton instance. */
	public static KISSDetailsUIRegistry getInstance() {
		return INSTANCE;
	}

	/** The registry. */
	private final HashMap<Class<? extends IIntrospectionDetailsItem>, DetailsUIHandlerBase> registry =
			new HashMap<Class<? extends IIntrospectionDetailsItem>, DetailsUIHandlerBase>();

	/** Constructor. */
	public KISSDetailsUIRegistry() {
		registerHandler(AllocationEditPartFactoryServiceIntrospectionDetailsItem.class,
				new AllocationEditPartFactoryServiceIntrospectionDetailsUIHandler());
		registerHandler(ConnectionCompositorServiceIntrospectionDetailsItem.class,
				new ConnectionCompositorServiceIntrospectionDetailsUIHandler());
		registerHandler(ConstraintCheckerServiceIntrospectionDetailsItem.class,
				new ConstraintCheckerServiceIntrospectionDetailsUIHandler());
		registerHandler(ContextMenuServiceIntrospectionDetailsItem.class,
				new ContextMenuServiceIntrospectionDetailsUIHandler());
		registerHandler(EclipseResourceStorageServiceIntrospectionDetailsItem.class,
				new EclipseResourceStorageProviderIntrospectionDetailsUIHandler());
		registerHandler(EditPartFactoryServiceIntrospectionDetailsItem.class,
				new EditPartFactoryServiceIntrospectionDetailsUIHandler());
		registerHandler(ElementCompositorServiceIntrospectionDetailsItem.class,
				new ElementCompositorServiceIntrospectionDetailsUIHandler());
		registerHandler(LibraryServiceIntrospectionDetailsItem.class,
				new LibraryServiceIntrospectionDetailsUIHandler());
		registerHandler(MigrationServiceIntrospectionDetailsItem.class,
				new MigrationServiceIntrospectionDetailsUIHandler());
		registerHandler(ModelEditorBindingServiceIntrospectionDetailsItem.class,
				new ModelEditorBindingServiceIntrospectionDetailsUIHandler());
		registerHandler(ModelElementHandlerServiceIntrospectionDetailsItem.class,
				new ModelElementHandlerServiceIntrospectionDetailsUIHandler());
		registerHandler(PrototypeServiceIntrospectionDetailsItem.class,
				new PrototypeServiceIntrospectionDetailsUIHandler());
		registerHandler(PersistencyServiceIntrospectionDetailsItem.class,
				new PersistencyServiceIntrospectionDetailsUIHandler());
		registerHandler(TransformationServiceIntrospectionDetailsItem.class,
				new TransformationServiceIntrospectionDetailsUIHandler());
		registerHandler(ConstraintVerificationServiceIntrospectionDetailsItem.class,
				new ConstraintServiceIntrospectionDetailsUIHandler());
		registerHandler(ConstraintUIServiceIntrospectionDetailsItem.class,
				new ConstraintUIServiceIntrospectionDetailsUIHandler());
	}

	/** Registers the given composite */
	public void registerHandler(Class<? extends IIntrospectionDetailsItem> clazz,
			DetailsUIHandlerBase detailsHandler) {
		registry.put(clazz, detailsHandler);
	}

	/** Returns the composite factory for the given class. */
	public DetailsUIHandlerBase getHandler(Class<? extends IIntrospectionDetailsItem> clazz) {
		return registry.get(clazz);
	}
}
