/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details.handler;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.TableLabelProviderBase;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeColumn;
import org.fortiss.tooling.kernel.extension.IConstraint;
import org.fortiss.tooling.kernel.introspection.items.ConstraintVerificationServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.service.IConstraintService;

/**
 * Introspection UI handler for the {@link IConstraintService}.
 * 
 * TODO(VA) @Flo: you should review
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 8F17D7B08111A51EFD312703D98E83FB
 */
public final class ConstraintServiceIntrospectionDetailsUIHandler extends
		EObjectAwareIntrospectionDetailsUIHandlerBase {

	/** {@inheritDoc} */
	@Override
	public Control createComposite(ScrolledComposite parent) {
		String heading = "Type to search registered constraint:";
		return createFilteredTreeInTabFolder(parent, heading, "", "Registered constraints");
	}

	/** {@inheritDoc} */
	@Override
	protected void createTreeColumns(Tree tree) {
		TreeColumn col0 = new TreeColumn(tree, SWT.LEFT);
		col0.setText("Constraint");
		col0.setWidth(900);
	}

	/** {@inheritDoc} */
	@Override
	protected ITreeContentProvider createContentProvider() {
		return new TreeContentProviderBase() {

			/** {@inheritDoc} */
			@Override
			public Object[] getChildren(Object parentElement) {
				if(parentElement == getInputObject()) {
					return getInputObject().getHandlerKeyClasses().toArray();
				}
				return new Object[0];
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected ITableLabelProvider createLabelProvider() {
		return new TableLabelProvider();
	}

	/** Table label provider for handler registrations with two classes. */
	protected static class TableLabelProvider extends TableLabelProviderBase {
		/** {@inheritDoc} */
		@Override
		public String getColumnText(Object element, int columnIndex) {
			return element instanceof IConstraint ? element.getClass().getName() : "";
		}
	}

	/** {@inheritDoc} */
	@Override
	protected ConstraintVerificationServiceIntrospectionDetailsItem getInputObject() {
		return (ConstraintVerificationServiceIntrospectionDetailsItem)dataItem;
	}
}
