/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.style;

import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.BLACK;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.RGB;
import org.fortiss.tooling.base.ui.utils.GCUtils.GCStateManager;

/**
 * Represents a style to be used in SWT spider chart graphics.
 *
 * @author mondal
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: E409257264305C2E695A14DF949C9E43
 */
public final class LineStyle extends ColorStyleBase {
	/** Solid, black line with width of one point. */
	public static final LineStyle SOLID_BLACK_1PT = new LineStyle(BLACK, 1, SWT.LINE_SOLID);
	/** The type of the line. */
	private final int swtLineStyle;
	/** The width of the line. */
	private final int width;

	/** Constructor */
	public LineStyle(RGB rgbColor, int width, int swtLineStyle) {
		super(rgbColor);
		this.width = width;
		this.swtLineStyle = swtLineStyle;
	}

	/** Constructor */
	public LineStyle(RGB rgbColor) {
		this(rgbColor, 1, SWT.LINE_SOLID);
	}

	/** Draws the line */
	public void draw(GCStateManager gcState, int x1, int y1, int x2, int y2) {
		gcState.foregroundStoreAndCreate(getRGBColor());
		gcState.lineStoreAndSet(width, swtLineStyle);
		gcState.GC().drawLine(x1, y1, x2, y2);
		gcState.lineRestore().foregroundRestoreAndDispose();
	}
}
